/**
 * (C) Copyright IBM Corp. 2006, 2012
 *
 * THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE 
 * ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE 
 * CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
 *
 * You can obtain a current copy of the Eclipse Public License from
 * http://www.opensource.org/licenses/eclipse-1.0.php
 *
 * @author : Endre Bak, ebak@de.ibm.com  
 * 
 * Flag       Date        Prog         Description
 * -------------------------------------------------------------------------------
 * 1565892    2006-12-04  ebak         Make SBLIM client JSR48 compliant
 * 1663270    2007-02-19  ebak         Minor performance problems
 * 1660756    2007-02-22  ebak         Embedded object support
 * 1720707    2007-05-17  ebak         Conventional Node factory for CIM-XML SAX parser
 * 2003590    2008-06-30  blaschke-oss Change licensing from CPL to EPL
 * 2524131    2009-01-21  raman_arora  Upgrade client to JDK 1.5 (Phase 1)
 * 2531371    2009-02-10  raman_arora  Upgrade client to JDK 1.5 (Phase 2)
 * 3511454    2012-03-27  blaschke-oss SAX nodes not reinitialized properly
 */

package org.sblim.cimclient.internal.cimxml.sax.node;

import java.util.ArrayList;

import org.sblim.cimclient.internal.cimxml.sax.SAXSession;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

/**
 * <pre>
 * ELEMENT EXPMETHODCALL (EXPPARAMVALUE*)
 * ATTLIST EXPMETHODCALL
 *   %CIMName;
 * </pre>
 */
/**
 * Class ExpMethodCallNode is responsible for
 * 
 */
public class ExpMethodCallNode extends Node implements NonVolatileIf {

	private String iName;

	private ArrayList<Node> iExpParamValNodeAList;

	/**
	 * Ctor.
	 */
	public ExpMethodCallNode() {
		super(EXPMETHODCALL);
	}

	public void addChild(Node pChild) {
		if (this.iExpParamValNodeAList == null) this.iExpParamValNodeAList = new ArrayList<Node>();
		this.iExpParamValNodeAList.add(pChild);
	}

	/**
	 * @param pSession
	 */
	@Override
	public void init(Attributes pAttribs, SAXSession pSession) throws SAXException {
		this.iName = getCIMName(pAttribs);
		if (this.iExpParamValNodeAList != null) this.iExpParamValNodeAList.clear();
	}

	/**
	 * @param pData
	 */
	@Override
	public void parseData(String pData) {
	// no data
	}

	@Override
	public void testChild(String pNodeNameEnum) throws SAXException {
		if (pNodeNameEnum != EXPPARAMVALUE) throw new SAXException(getNodeName()
				+ " node can have " + EXPPARAMVALUE + " child only! " + pNodeNameEnum
				+ " is invalid!");
	}

	/**
	 * @param pChild
	 */
	@Override
	public void childParsed(Node pChild) {
	// nothing to do yet

	}

	@Override
	public void testCompletness() {
	// no mandatory child
	}

	/**
	 * getName
	 * 
	 * @return String
	 */
	public String getName() {
		return this.iName;
	}

}
